# ACTIVESTATE ACTIVETCL PRODUCT INFO BEGIN -*- tcl -*-
# Copyright (C) 2001-2008 ActiveState Software Inc
# Nov 04, 2014
#

#
# Extension code to tcl8.5/library/init.tcl declaring the
# version information for TclDevKit.
#
# ActiveState Tcl Dev Kit 5.4.0.298612 Linux/x86, Tue Nov 04 18:35:33 PST 2014
#

namespace eval ::activestate {
    # Declare product specific configuration

    variable  {TclDevKit}
    array set {TclDevKit} {
	build         {298612}
	product       {TclDevKit}
	release       {5.4.0}
	tcl,revision  {e03818474b0c94354ffb8d2600d18a84a6fbecfe}
	tk,revision   {148dda7a6fa6be6b9196973f93beb31e28baab4b}
	maturity      {final}
	arch          {linux-ix86}
	buildtime,sec {1415154933}
	buildtime,fmt {Tue Nov 04 18:35:33 PST 2014}
	as,mode       {pro}
    }

    # Extend overall module information

    variable  config
    array set config {
	{TclDevKit} {ActiveState Tcl Dev Kit 5.4.0.298612 Linux/x86 @ Tue Nov 04 18:35:33 PST 2014 e03818474b0c94354ffb8d2600d18a84a6fbecfe / pro}
    }
}

package provide {TclDevKit} {5.4.0.298612}

# ACTIVESTATE ACTIVETCL PRODUCT INFO END
